@@ -1050,6 +1050,12 @@ class RunAndMail(Subcommand):
         parser.add_argument('cmd', metavar='COMMAND',
                             help="Command which should be ran, and result of which will be emailed")
 
+        parser.add_argument('--keep-exit-code', action='store_true',
+                            help="Exit with same return code as subprocess.  If "
+                            "this is not specified, `run-n-mail` will normally "
+                            "exit with code 0 regardless of what happens with "
+                            "the subprocess.")
+
     def run(self, args):
         from rattail.mail import send_email
 
@@ -1076,21 +1082,24 @@ class RunAndMail(Subcommand):
 
         if args.skip_if_empty and not output:
             log.info("command had no output, so will skip sending email")
-            return
+            # return
 
-        kwargs = {}
-        if args.subject:
-            kwargs['subject_template'] = args.subject
+        else: # send email
+            kwargs = {}
+            if args.subject:
+                kwargs['subject_template'] = args.subject
+            send_email(self.config, args.key, {
+                'cmd': cmd,
+                'run_began': run_began,
+                'run_ended': run_ended,
+                'runtime': runtime,
+                'runtime_pretty': runtime_pretty,
+                'retcode': retcode,
+                'output': output,
+            }, **kwargs)
 
-        send_email(self.config, args.key, {
-            'cmd': cmd,
-            'run_began': run_began,
-            'run_ended': run_ended,
-            'runtime': runtime,
-            'runtime_pretty': runtime_pretty,
-            'retcode': retcode,
-            'output': output,
-        }, **kwargs)
+        if retcode and args.keep_exit_code:
+            sys.exit(retcode)
 
 
 class RunSQL(Subcommand):
