@@ -56,7 +56,7 @@ def parse_bool(value):
         return None
     if isinstance(value, bool):
         return value
-    if value.lower() in ('true', 'yes', 'on', '1'):
+    if six.text_type(value).lower() in ('true', 'yes', 'y', 'on', '1'):
         return True
     return False
 
