@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2018 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -26,6 +26,8 @@ Batch data models
 
 from __future__ import unicode_literals, absolute_import
 
-from .core import (filename_column,
-                   BatchMixin, BaseFileBatchMixin, FileBatchMixin,
+# TODO: remove this once callers are updated
+from rattail.db.core import filename_column
+
+from .core import (BatchMixin, BaseFileBatchMixin, FileBatchMixin,
                    BatchRowMixin, ProductBatchRowMixin)
