@@ -53,6 +53,12 @@ class Role(Base):
     Name for the role.  Each role must have a name, which must be unique.
     """)
 
+    adminish = sa.Column(sa.Boolean(), nullable=True, doc="""
+    Flag indicating that the role is "admin-ish" - i.e. only users who
+    belong to the true Administrator role, should be allowed to
+    (un)assign users to this role.
+    """)
+
     session_timeout = sa.Column(sa.Integer(), nullable=True, doc="""
     Optional session timeout value for the role, in seconds.  If this is set to
     zero, the role's users will have no session timeout.  A value of ``None``
