@@ -150,6 +150,7 @@ class LuigiHandler(GenericHandler):
                 return task
 
     def launch_overnight_task(self, task, date,
+                              keep_config=True,
                               email_if_empty=True,
                               email_key=None,
                               wait=True,
@@ -163,6 +164,11 @@ class LuigiHandler(GenericHandler):
 
         :param date: Date for which task should run.
 
+        :param keep_config: If true (the default) then the ``rattail
+           overnight`` command will be invoked with the same config
+           file(s) which are effective in the current/parent process.
+           If false, it will be invoked only with ``app/silent.conf``.
+
         :param email_if_empty: If true (the default), then email will
            be sent when the task command completes, even if it
            produces no output.  If false, then email is sent only if
@@ -182,10 +188,11 @@ class LuigiHandler(GenericHandler):
            but do not actually run it.
         """
         appdir = self.config.appdir()
-        env = {
-            'PYTHONPATH': appdir,
-            'RATTAIL_CONFIG_FILES': os.pathsep.join(self.config.files_read),
-        }
+        env = {'PYTHONPATH': appdir}
+        if keep_config:
+            env['RATTAIL_CONFIG_FILES'] = os.pathsep.join(self.config.files_read)
+        else:
+            env['RATTAIL_CONFIG_FILES'] = os.path.join(appdir, 'silent.conf')
 
         # build our command, which will vary per caller request.  by
         # default we do not use the shell to run command, but in some
