@@ -219,6 +219,38 @@ class PeopleHandler(GenericHandler, MergeMixin):
 
         return email
 
+    def add_address(self, person, type=None,
+                    street=None, street2=None,
+                    city=None, state=None, zipcode=None,
+                    invalid=False, preferred=False, **kwargs):
+        """
+        Add a physical/mailing address record for the person.
+
+        :param person: Reference to a ``Person`` record.
+        :param type: Type of address to add.
+        :param street: Street (line 1) for the address.
+        :param street2: Street (line 2) for the address.
+        :param city: City for the address.
+        :param state: State for the address.
+        :param zipcode: Zipcode for the address.
+        :param invalid: Boolean indicating the address is known to
+           *not* be valid.
+        :param preferred: Boolean indicating that this should (or not)
+           be the "preferred" address for the person.
+        """
+        address = person.add_address(type=type,
+                                     street=street,
+                                     street2=street2,
+                                     city=city,
+                                     state=state,
+                                     zipcode=zipcode,
+                                     invalid=invalid,
+                                     flush=False)
+        if preferred:
+            person.set_primary_address(address)
+
+        return address
+
     def ensure_address(self, person, **kwargs):
         """
         Returns the default address record associated with the given
@@ -226,11 +258,34 @@ class PeopleHandler(GenericHandler, MergeMixin):
         """
         address = person.first_address()
         if not address:
-            address = person.add_address(**kwargs)
-            # TODO: this might be a good idea..maybe if a kwarg flag is set?
-            # person.set_primary_address(address)
+            address = self.add_address(person, **kwargs)
         return address
 
+    def update_address(self, person, address, **kwargs):
+        """
+        Update the given address with the given data.
+        """
+        if 'type' in kwargs:
+            address.type = kwargs['type']
+
+        if 'street' in kwargs:
+            address.street = kwargs['street']
+
+        if 'street2' in kwargs:
+            address.street2 = kwargs['street2']
+
+        if 'city' in kwargs:
+            address.city = kwargs['city']
+
+        if 'state' in kwargs:
+            address.state = kwargs['state']
+
+        if 'zipcode' in kwargs:
+            address.zipcode = kwargs['zipcode']
+
+        if 'invalid' in kwargs:
+            self.mark_address_invalid(person, address, kwargs['invalid'])
+
     def address_is_invalid(self, person, address, **kwargs):
         """
         Returns a boolean indicating if the given person's address is
